| scpi-package | R Documentation |
scpi: A Package to Compute Synthetic Control Prediction Intervals With Multiple Treated Units and Staggered AdoptionThe package implements estimation, inference procedures, and produces plots for Synthetic Control (SC) methods using least squares, lasso, ridge, or simplex-type constraints. Uncertainty is quantified using prediction intervals according to \insertCitecattaneo2021methodological-JASA;textualscpi and \insertCitecattaneo2025methodological-RESTAT;textualscpi.
Included functions are: scdata and scdataMulti for data preparation, scest for point estimation, scpi for inference procedures, and scplot and scplotMulti for plots.
print() and summary() methods are available for scest and scpi.
Companion Stata and Python packages are described in \insertCitecattaneo2025software-JSS;textualscpi.
Related Stata, R, and Python packages useful for inference in SC designs are described in the following website:
https://nppackages.github.io/scpi/
For an introduction to synthetic control methods, see \insertCiteabadie2021UsingSyntheticControls;textualscpi and references therein.
Matias Cattaneo, Princeton University. cattaneo@princeton.edu.
Yingjie Feng, Tsinghua University. fengyj@sem.tsinghua.edu.cn.
Filippo Palomba, Princeton University (maintainer). fpalomba@princeton.edu.
Rocio Titiunik, Princeton University. titiunik@princeton.edu.
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.